# ugo=rw,o=rx
DEFAULT_CHMOD_MODE = 0o775
DEFAULT_UMASK = 0o777-DEFAULT_CHMOD_MODE
